library(dplyr)
library(readxl)
salary = read_excel('salary.xlsx')

models_sessio_5 = list(
  m.yr = lm(sl~yr, data = salary),
  m.yd = lm(sl~yd, data = salary),
  m.yr_yd = lm(sl~yr+yd, data = salary),
  m.rk = lm(sl~rk, data = salary),
  m.rk_dg = lm(sl~rk+dg, data = salary),
  m.rk_dg_inter = lm(sl~rk+dg+rk:dg, data = salary),
  m.rk_yr = lm(sl~rk+yr, data = salary),
  m.rk_yr_inter = lm(sl~rk+yr+rk:yr, data = salary))
# incorporem els elements de la llista per poder 
# cridar-los directament. 
attach(models_sessio_5)

m.yr

#Selecció d’un model de regressió lineal

###R^2
SQT = with(salary, sum( (sl-mean(sl))^2 ))

R2 = function(m){
  SQR = sum(residuals(m)^2)
  1-SQR/SQT
}

R2(m.yr)

sapply(models_sessio_5, R2)

###R^2 Ajustat
R2A = function(m){
  n=52
  nbetas=length(coef(m))
  SQR = sum(residuals(m)^2)
  1-(SQR/(n-nbetas))/(SQT/(n-1))
}
sapply(models_sessio_5, R2A)


AIC = function(m)
{
  extractAIC(m)[2]
}
sapply(models_sessio_5, AIC)

##Tria automatica
res=c()
for(m in 1:5){
  for(id in combn(5,m,simplify = FALSE)){
    idx=names(salary)[id]
    m=lm(sl~., data = select(salary, sl, all_of(idx)))
    
    avaluacio = AIC(m)
    names(avaluacio) = paste(idx, collapse="+")
    res=c(res,avaluacio)
  }
}
sort(res)

##Metode selecio automatica forward-backward

step(lm(sl~.,data=salary)) #criteri AIC,cerca backward
step(lm(sl~.,data=salary),direction = "both") #criteri AIC,cerca forward-backward

#Inferència amb el model de regressió lineal


##Assumpcions de model de RL


#Contrast
summary(m.rk)

#Predicció a través del model lineal construït
dfpred = data.frame(sx = 'female', rk = 'full', yr = 6, 
                    dg = 'doctorate', yd = 20)
predict(m.rk_yr, newdata = dfpred)

#interval de confiança
predict(m.rk_yr, newdata = dfpred, interval = 'confidence', level = 0.95)
#Si tenim prous dades és creible encara que no normalitat residus

#interval predictiu
predict(m.rk_yr, newdata = dfpred, interval = 'prediction', level = 0.95)
#Independent del nombre de dades , No és creible si no normalitat residus

